# Project description
https://packaging.python.org/tutorials/packaging-projects/


> tokenmain

py -m build

py -m twine upload --repository testpypi dist/*

py -m twine upload --repository tpypi dist/*
__token__

pypi-AgEIcHlwaS5vcmcCJDgwZjdmZTQ5LWE3YTUtNDMwMi1iYWQ0LWY1NDNmZTU5MjcyYwACJXsicGVybWlzc2lvbnMiOiAidXNlciIsICJ2ZXJzaW9uIjogMX0AAAYgjY7geJqo_d8fgfnltaoWQEGa3P6uQbiVBwWx5f3hvaU

